---
title: Rasa Chatbot Demo
separator: <!--s-->
verticalSeparator: <!--v-->
theme: solarized
revealOptions:
    transition: fade
	controls: false
---

# Wikipedia Fact Chatbot

David Fuhry, Lukas Gehrke, Leonard Haas, 

Lucas Schons, Jonas Wolff

<!--s-->

### Inhalt

* Thema & Forschungsfrage
* Lösungsansatz
* Ergebnisse

<!--s-->

### Thema - Chatbot

Definition:

> Ein Chatterbot, Chatbot oder kurz Bot ist ein _textbasiertes Dialogsystem_, welches das Chatten mit einem technischen System erlaubt. Er hat je einen Bereich zur Textein- und -ausgabe, über die sich in natürlicher Sprache mit dem dahinterstehenden System kommunizieren lässt.

<!--s-->

### Thema - RASA Chatbot

RASA ist ein Framework für die Nutzung von **Chatbots**. Das System muss mit Facts befüllt
werden, um Antworten generieren zu können.

> The Rasa Stack is a set of open source machine learning tools for developers to create contextual chatbots and assistants. 

<!--s-->

### Thema - Architektur von RASA

Note: Bild von Rasa NLU und Core Architektur erklären

<!--s-->

### Forschungsfrage

- _Kann man dieses Wissen aus Texten akquirieren?_  
- _Kann dies automatisch mit Textquellen durchgeführt werden?_  

Dies soll anhand der _Wikipedia-Einträge von Physikern_ erprobt werden

<!--s-->

### Inhalt

* ~~Thema & Forschungsfrage~~
* Lösungsansatz
* Ergebnisse

<!--s-->

### Lösumgsansatz - RASA Bot konfigurierern

* Für Training eines Bots werden _entities_, _text_ und _intents_ benötigt
* Definition _intent_ aus [RASA Docs](https://rasa.com/docs/nlu/dataformat/): 'The intent is the intent that should be associated with the text.'

<!--s-->

### Lösumgsansatz - RASA Bot konfigurierern

* Aufstellen von Intents zu Physikern:
Note: Schaubild einfügen

<!--s-->

### Lösungsansatz - Datenquelle

* 982 englischsprachige Wikipedia-Artikel
* Über Wikipedia API
* HTML-Formatierung
* Ca. 550 Wörter/Artikel 
	* Großteil um 400 Wörter
Note: Bild zu dem Artikel von irgendeinem sowjetischen Physiker :)

<!--s-->

### Lösungsansatz - Processing

* Eigenes R-package 'wikiproc' 
* Download der Artikel als HTML, cleaning, Extraktion der Intents
Note: Zu jedem Intent ein `R`-Skript
Note: Master lädt die Artikel, speichert sie in einem Dataframe und ruft für jeden Artikel das clean_html-Skript und die Intent-processing-Skripte auf. Die extrahierten Informationen werden in einem neuen data-frame gespeichert. Außerdem wird das .tsv für den Bot generiert
```
├── packages.list
├── script
│   └── master.R
└── wikiproc
    ├── DESCRIPTION
    ├── NAMESPACE
    ├── R
    ├── man
    └── tests
```

<!--s-->

### Lösungsansatz - Processing, Extraktion Intents
  
* Beispiel `R/get_awards.R`
* Nutze _NER-Entities_ und _Regex_

<!--s-->

### Lösungsansatz - Processing, Extraktion Intents

* Beispiel `R/get_spouse.R`
* Nutze _Pattern_ sowie _NER-Entities_ und _POS-Tags_

<!--s-->

### Lösungsansatz - Gesamtarchitektur

* `data.tsv` als Schnittstelle
Note: Schaubild der Gesamtarchitektur einfügen, AUF JEDEN FALL mit docker-Wal

```
rasa
├── actions.py       - Custom Actions
├── domain.yml       - Entitäten, Antwortvorlagen
├── nlu.md           - Intents, Fragebeispiele
├── nlu_config.yml   - Pipeline
├── data
│   └── data.tsv     - Daten für den Bot
└── stories.md       - Gesprächsverläufe
```

<!--s-->

### Vorführung RASA - Bot

Note: I see what you did there

<!--s-->

### Inhalt

* ~~Thema & Forschungsfrage~~
* ~~Lösungsansatz~~
* Ergebnisse

<!--s-->

### Ergebnisse mit Plots

Note: fancy plots mit precision und recall zu awards, birthdate und spouse

<!--s-->

### Bewertung Software/Datengrundlage II

#### 1. Rasa-Bot
* (-) RASA-Software schwierig aufzusetzen (keine Dokumentation in Beispielen, keine Beispiele in der Dokumentation)
* (+) NLP funktioniert in Rasa sehr gut
* (+) Übersichtliches Skript (actions.py)
* (+) Definierung komplexer Gesprächsverläufe möglich

<!--s-->

### Bewertung Software/Datengrundlage II

#### 1. Rasa-Bot

* Bewertung Wikipedia-Artikel als unstrukturierte Datengrundlage
* (+) relativ ähnlicher Aufbau
* (-) dennoch im Detail unterschiede ("persönliche Note" unterschiedlicher Autoren)
* (-) unterschiedlich ausführlich

<!--s-->

### Beantwortung der Forschungsfrage

* **Hauptpunkt** Definieren der Intents für Bot sollte vorab geschehen
Note: (Wäre möglich, aber sinnvoll, denn Intents sind Grundlage für Funktionieren von Rasa-Architektur)
* Informationen zu Intents unterschiedlich schwierig aus Text zu extrahieren
Note: Verfahren teilweise allgemein verwendbar, tlw. auch von der Domäne abhängig

<!--s-->

### Ergebnisse

* _Kann man dieses Wissen aus Texten akquirieren?_ - ¯\\\_(ツ)_/¯
  - Ja, nutze Pattern, NER
* _Kann man dies automatische mit Textquellen geschehen?_ - ¯\\\_(ツ)_/¯
  - Nein. Intents sollten vorher generiert werden, dann lässt sich das Wissen mit **auf den Intent und die Datengrundlage zugeschnittenen Verfahren** extrahieren

<!--s-->
